@@ -1,4 +1,4 @@
-from typing import Any, Dict, Type, TypeVar
+from typing import Any, Dict, Type, TypeVar, List, Set, Dict
 from dataclasses import is_dataclass, asdict
 
 import sys
@@ -7,7 +7,7 @@ T = TypeVar("T")
 
 
 def _to_dataclass_38(dataclass_type: Type[T], data: Any) -> T:
-    from typing import Any, Dict, get_args, get_type_hints, get_origin
+    from typing import get_args, get_type_hints, get_origin
 
     dict_value: Any
 
